function s = spider_trace(et, shear, delay)

% Calculates the theoretical ideal SPIDER trace for a given input electric
% field, frequency shear, and delay

% et is the electric field, and it should be a function of time.
% shear is the frequency shear between pulse replicas, and it has units 
% of 2*pi/[(number of points)*(temporal resolution)].
% delay is the temporal delay between pulse replicas.

et = et(:);
n = length(et);
ew = 1/sqrt(n)*fftc(et);
et_shear = circshift(et, delay);
ew_shear = 1/sqrt(n)*fftc(et_shear);
ew_dw = circshift(ew_shear, shear);

s = abs(ew + ew_dw).^2;