function style_plot(ax, h, style)

% A general function used by the Trebino research group to uniformly format
% our plots.  Contains settings for plotting FROG traces ('frog_trace'), 
% SPIDER traces ('spider'), and electric fields in time ('frog_time') or 
% frequency ('frog_freq').

threshold = .0005;      % used by find_plot_domain.m to determine useful plotting range
phase_limit = 4;        % multiple of pi

if iscell(h)
    h1 = h{1};
else
    if length(h) > 1
        h1 = h(1);
    else
        h1 = h;
    end
end
dat = get(h1, 'YData');
x = get(h1, 'XData');
[ind_min ind_max] = find_plot_domain(dat, threshold);

switch style
    case 'spider'
        set(h, 'LineWidth', 3)
        if length(h) > 1
            set(h(2), 'LineWidth', 2)
        end
        set(ax, 'FontSize', 20, 'LineWidth', 3, 'FontName', 'Helvetica', ...
                 'FontWeight', 'Bold', 'XLim', [x(ind_min) x(ind_max)], ...
                 'YLim', [0 1])
        xlabel('Angular Frequency [(\omega - \omega_0)/\delta\omega]')
        ylabel('Spectral Intensity [a.u.]')
    case 'frog_time'
        h2 = h{2};
        ax1 = ax(1);
        ax2 = ax(2);
        p = phase_limit;
        
        phase = get(h2, 'YData');
        set(h2, 'YData', phase - phase(length(phase)/2))
        
        set(h1, 'LineWidth', 3, 'Color', [1 0 0])
        set(h2, 'LineWidth', 3, 'Color', [0 0 1])
        
        set(ax1, 'FontSize', 20, 'LineWidth', 3, 'FontName', 'Helvetica', ...
                 'FontWeight', 'Bold', 'XLim', [x(ind_min) x(ind_max)], ...
                 'YLim', [0 1], 'YColor', [1 0 0])
        set(get(ax1, 'XLabel'), 'String', 'Time [t/\deltat]', 'FontSize', 20, ...
                                'FontWeight', 'Bold')
        set(get(ax1, 'YLabel'), 'String', 'Intensity [a.u.]', 'FontSize', 20, ...
                                'FontWeight', 'Bold')
        set(ax2, 'FontSize', 20, 'LineWidth', 3, 'FontName', 'Helvetica', ...
                 'FontWeight', 'Bold', 'XLim', [x(ind_min) x(ind_max)], ...
                 'YColor', [0 0 1], 'YLim', [-p*pi p*pi], ...
                 'YTick', -p*pi:2*pi:p*pi, 'YTickLabel', -p:2:p)
        set(get(ax2, 'YLabel'), 'String', 'Phase [\pi radians]', ...
                                'FontSize', 20, 'FontWeight', 'Bold')
                            
        %set(ax, 'position', [.14 .17 .75 .75])
    case 'frog_freq'
        h2 = h{2};
        ax1 = ax(1);
        ax2 = ax(2);
        p = phase_limit;
        
        phase = get(h2, 'YData');
        set(h2, 'YData', phase - phase(length(phase)/2))
        
        set(h1, 'LineWidth', 3, 'Color', [0 0.5 0])
        set(h2, 'LineWidth', 3, 'Color', [0.6 0 0.8])
        
        set(ax1, 'FontSize', 20, 'LineWidth', 3, 'FontName', 'Helvetica', ...
                 'FontWeight', 'Bold', 'XLim', [x(ind_min) x(ind_max)], ...
                 'YLim', [0 1], 'YColor', [0, 0.5, 0])
        set(get(ax1, 'XLabel'), 'String', 'Frequency [(\omega - \omega_0)/\delta\omega]', ...
                                'FontSize', 20, ...
                                'FontWeight', 'Bold')
        set(get(ax1, 'YLabel'), 'String', 'Intensity [a.u.]', 'FontSize', 20, ...
                                'FontWeight', 'Bold')
        set(ax2, 'FontSize', 20, 'LineWidth', 3, 'FontName', 'Helvetica', ...
                 'FontWeight', 'Bold', 'XLim', [x(ind_min) x(ind_max)], ...
                 'YColor', [0.6, 0, 0.8], 'YLim', [-p*pi p*pi], ...
                 'YTick', -p*pi:2*pi:p*pi, 'YTickLabel', -p:2:p)
        set(get(ax2, 'YLabel'), 'String', 'Phase [\pi radians]', ...
                                'FontSize', 20, 'FontWeight', 'Bold')
                            
        %set(ax, 'position', [.14 .17 .75 .75])
        
    case 'frog_trace'
        isig = get(h, 'CData');
        colormap(ax, frogmap());
        [index_min index_max] = find_plot_domain(isig, threshold);
        xmin = x(index_min(1)); xmax = x(index_max(1));
        ymin = x(index_min(2)); ymax = x(index_max(2));
        set(ax, 'LineWidth', 3, 'FontSize', 20, 'FontName', 'Helvetica', ...
                'FontWeight', 'Bold', 'XLim', [xmin xmax], ...
                'YLim', [ymin ymax])
            
        set(get(ax, 'XLabel'), 'String', 'Time [t/\deltat]', ...
                               'FontSize', 20, 'FontName', 'Helvetica', ...
                               'FontWeight', 'Bold')
        
        set(get(ax, 'YLabel'), 'String', 'Frequency [(\omega - \omega_0)/\delta\omega]', ...
                               'FontSize', 20, 'FontName', 'Helvetica', ...
                               'FontWeight', 'Bold')
        
end